@@ -3,8 +3,8 @@
 #'
 #' @param result A summarised_result object.
 #' @param directory Directory to create the shiny.
-#' @param logo Name of a logo or path to a logo. If NULL no logo is included.
-#' Only svg format allowed for the moment.
+#' @param logo Name of a logo or path to a logo. If NULL no logo is obtained
+#' from theme.
 #' @param title title of the shiny
 #' @param background Whether to include a background panel. Background panel
 #' content will be controlled from the generated background.md file.
@@ -41,7 +41,7 @@
 #'
 exportStaticApp <- function(result,
                             directory,
-                            logo = "ohdsi",
+                            logo = NULL,
                             title = "",
                             background = TRUE,
                             summary = TRUE,
@@ -66,6 +66,7 @@ exportStaticApp <- function(result,
   omopgenerics::assertLogical(updateButtons, length = 1)
   omopgenerics::assertLogical(includeOneChoiceFilters, length = 1)
   theme <- validateTheme(theme = theme)
+  logo <- validateLogo(logo = logo, theme = theme)
   template <- validateTemplate(template = template, theme = theme)
   panelDetails <- validatePanelDetails(panelDetails, result, includeOneChoiceFilters)
   panelStructure <- validatePanelStructure(panelStructure, names(panelDetails))
@@ -133,13 +134,16 @@ exportStaticApp <- function(result,
   # export report
   if (report) {
     # create report
-    report <- createReport(panelDetails, title, !is.null(template))
+    reportCont <- createReport(panelDetails, title, !is.null(template))
 
     # export files
-    exportReport(report = report, directory = directory)
+    exportReport(report = reportCont, directory = directory)
     exportTemplate(template = template, directory = directory)
   }
 
+  # add readme
+  copyReadme(shiny = TRUE, report = report, title = title, directory = directory)
+
   cli::cli_inform(c("v" = "Shiny created in: {.pkg {directory}}"))
 
   # open shiny
@@ -186,11 +190,38 @@ copyLogos <- function(logo, directory) {
       file.copy(from = logo, to = to, overwrite = TRUE)
     }
     return(nm)
+  } else if (grepl("https://", logo, fixed = TRUE)) {
+    return(downloadLogo(url = logo, directory = directory))
   } else {
     cli::cli_warn(c("!" = "Logo couldn't be found."))
     return(NULL)
   }
 }
+downloadLogo <- function(url, directory) {
+  tf <- tempfile()
+  utils::download.file(url = url, destfile = tf, mode = "wb")
+
+  # detect extension
+  x <- readBin(con = tf, what = "raw", n = 10)
+  if (identical(x[1:8], charToRaw("\x89PNG\r\n\x1a\n"))) {
+    nm <- "logo.png"
+  } else if (identical(x[1:3], charToRaw("\xFF\xD8\xFF"))) {
+    nm <- "logo.jpg"
+  } else if (grepl("<svg", rawToChar(x))) {
+    nm <- "logo.svg"
+  } else {
+    nm <- "logo"
+  }
+
+  # copy document
+  to <- file.path(directory, "www", nm)
+  file.copy(from = tf, to = to, overwrite = TRUE)
+
+  # eliminate temp file
+  file.remove(tf)
+
+  return(nm)
+}
 logoPath <- function(logo) {
   lowLogo <- stringr::str_to_lower(logo)
   # add more logoKeywords in data-raw/internalData
